import { AbstractLevel } from "abstract-level";
export type LevelBatchOptions = {
    interval: number;
    onError?: (error: any) => void;
};
export type LazyLevelOptions = {
    batch?: LevelBatchOptions;
};
type MaybePromise<T> = Promise<T> | T;
export interface SimpleLevel {
    status(): MaybePromise<"opening" | "open" | "closing" | "closed">;
    close(): Promise<void>;
    open(): Promise<void>;
    get(key: string): Promise<Uint8Array | undefined>;
    put(key: string, value: Uint8Array): any;
    del(key: any): Promise<void>;
    sublevel(name: string): MaybePromise<SimpleLevel>;
    clear(): Promise<void>;
    idle?(): Promise<void>;
}
export default class LazyLevel implements SimpleLevel {
    private _store;
    private _interval;
    private _txQueue?;
    private _tempStore?;
    private _tempDeleted?;
    private _txPromise?;
    private _opts?;
    private _sublevels;
    constructor(store: AbstractLevel<any, any, any>, opts?: LazyLevelOptions | {
        batch: boolean;
    });
    status(): "opening" | "open" | "closing" | "closed";
    idle(): Promise<void>;
    close(): Promise<void>;
    open(): Promise<void>;
    get(key: string): Promise<Uint8Array | undefined>;
    getByPrefix(prefix: string): Promise<Uint8Array[]>;
    clear(clearStore?: boolean): Promise<void>;
    deleteByPrefix(prefix: string): Promise<void>;
    put(key: string, value: Uint8Array): Promise<void>;
    del(key: string): Promise<void>;
    delAll(keys: string[]): Promise<void>;
    sublevel(name: string): Promise<LazyLevel>;
}
export {};
